polyfemos.front.sohplot.sohplot — polyfemos 0.3.29 documentation

# polyfemos.front.sohplot.sohplot

Class `SOHPlot` for reading and plotting state of health data

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Private Functions

`polyfemos.front.sohplot.sohplot.` `_get_line_source`(data, datarealtimeness=False)
  Parameters

    - data (list) – a list consisting of `DataPoint` instances

    - datarealtimeness (bool, optional) – If `True`, datarealtimeness starttime value will be used to plot ‘square’ plots.

  Return type

    `ColumnDataSource`

  Returns

`polyfemos.front.sohplot.sohplot.` `_plot_line_source`(bokeh_figure, line_source, color='#000000', cross=False)
  Parameters

    - bokeh_figure (`Figure`) –

    - line_source (`ColumnDataSource`) –

    - color (str, optional) – color of the line or cross as string containing RGB value as hexadecimals (#RRBBGG), defaults to black

    - cross (bool, optional) – defaults to `False`. If `True`, crosses are plotted in any case. If `False`, the cross marker is used for plotting If only 1 datapoint is present.

Classes

`SOHPlot`([station_id, sohpar_name, …]) | Class for parsing and plotting the state of health data of given station and sohpar combination.